"use client";
import React, { createContext, useContext, useState, useCallback, useMemo } from 'react';
import Script from 'next/script.js';
import { RECAPTCHA_LOADED_EVENT, getRecaptchaScriptSrc } from './utils.js';

const ReCaptchaContext = createContext({
    reCaptchaKey: null,
    language: null,
    useEnterprise: false,
    useRecaptchaNet: false,
    isLoaded: false,
    isError: false,
    error: null,
});
const useReCaptchaContext = () => useContext(ReCaptchaContext);
const ReCaptchaProvider = ({ reCaptchaKey: passedReCaptchaKey, useEnterprise = false, useRecaptchaNet = false, language = null, children, strategy = "afterInteractive", src: passedSrc, onReady: passedOnReady, onError: passedOnError, ...props }) => {
    const [isLoaded, setIsLoaded] = useState(false);
    const [error, setError] = useState(null);
    const isError = !!error;
    const reCaptchaKey = passedReCaptchaKey || process.env.NEXT_PUBLIC_RECAPTCHA_SITE_KEY || null;
    const src = passedSrc ||
        getRecaptchaScriptSrc({ reCaptchaKey, language, useRecaptchaNet, useEnterprise }) ||
        null;
    // Handle script load
    const onReady = useCallback(() => {
        setError(null);
        setIsLoaded(true);
        window.dispatchEvent(new Event(RECAPTCHA_LOADED_EVENT));
        passedOnReady?.();
    }, [passedOnReady]);
    // Handle script error
    const onError = useCallback((e) => {
        setError(e);
        passedOnError?.(e);
    }, [passedOnError]);
    // Prevent unnecessary rerenders
    const value = useMemo(() => ({
        reCaptchaKey,
        language,
        useEnterprise,
        useRecaptchaNet,
        isLoaded: isLoaded,
        isError,
        error,
    }), [reCaptchaKey, language, useEnterprise, useRecaptchaNet, isLoaded, isError, error]);
    return (React.createElement(ReCaptchaContext.Provider, { value: value },
        children,
        React.createElement(Script, { src: src, strategy: strategy, onReady: onReady, onError: onError, ...props })));
};

export { ReCaptchaContext, ReCaptchaProvider, useReCaptchaContext };
