import type { ReCaptchaContextProps } from "./ReCaptchaProvider.js";
import type { IReCaptcha } from "./recaptcha.types.js";
export interface useReCaptchaProps extends ReCaptchaContextProps {
    /** reCAPTCHA instance */
    grecaptcha: IReCaptcha | null;
    /**
     * Executes the reCAPTCHA verification process for a given action.
     * Actions may only contain alphanumeric characters and slashes, and must not be user-specific.
     */
    executeRecaptcha: (action: string) => Promise<string>;
}
/**
 * Custom hook to use Google reCAPTCHA v3.
 *
 * @param [reCaptchaKey] - Optional reCAPTCHA site key. If not provided, it will use the key from the context.
 * @returns An object containing the reCAPTCHA context, grecaptcha instance, reCaptchaKey, and executeRecaptcha function.
 *
 * @example
 * const { executeRecaptcha } = useReCaptcha();
 *
 * const handleSubmit = async () => {
 *   try {
 *     const token = await executeRecaptcha('your_action');
 *     // Use the token for verification
 *   } catch (error) {
 *     console.error('ReCAPTCHA error:', error);
 *   }
 * };
 */
export declare const useReCaptcha: (reCaptchaKey?: string) => useReCaptchaProps;
